"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sourceNodes = void 0;

var _isString = _interopRequireDefault(require("lodash/isString"));

var _utils = require("./utils");

var _constants = require("./constants");

var _manifest = require("./utils/manifest");

var _url = require("./utils/url");

var _api = require("./utils/api");

var _createNode = require("./utils/createNode");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Copyright © 2019 Province of British Columbia
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// Created by Patrick Simonian on 2019-06-04.
//
const sourceNodes = async ({
  getNodes,
  actions,
  createNodeId
}, {
  githubAccessToken,
  files
}) => {
  const {
    createNode
  } = actions;

  if (!(0, _utils.areOptionsOkay)(githubAccessToken, files)) {
    throw new Error(_constants.ERRORS.BAD_OPTIONS);
  }

  let manifest = [];

  if ((0, _isString.default)(files)) {
    const manifestSourceType = files;
    manifest = (0, _utils.getManifestInFileSystem)(getNodes, manifestSourceType);
  } else {
    manifest = files.map(f => {
      if ((0, _isString.default)(f)) return {
        url: f
      };
      return f;
    });
  } // validate files and filter


  const filteredManifest = (0, _manifest.validateAndFilterManifest)(manifest); // grab seperate urls from the rest of the metadata

  const urlMap = filteredManifest.reduce((map, currentUrlObj) => {
    const {
      url,
      ...rest
    } = currentUrlObj;
    map.set(url, rest || null);
    return map;
  }, new Map()); // convert into a github object

  const fetchFileList = Array.from(urlMap.keys()).map(url => (0, _url.extractInformationFromGithubUrl)(url)).map(({
    repo,
    owner,
    filepath,
    ref
  }) => (0, _url.createFetchFileRoute)(repo, owner, filepath, ref));
  const rawFiles = await Promise.all(fetchFileList.map(path => (0, _api.fetchFile)(path, githubAccessToken))); // filter out files that didn't fetch and then decode b64 content

  const decodedFiles = rawFiles.filter(f => f).map(_utils.decodeFileContent);
  return decodedFiles.map(file => {
    const {
      html_url
    } = file; // get meta data from urlMap based on this url

    const metadata = urlMap.get(html_url);
    return createNode((0, _createNode.createNodeObject)(createNodeId, file, metadata));
  });
};

exports.sourceNodes = sourceNodes;