"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createFetchFileRoute = exports.extractInformationFromGithubUrl = void 0;

var _gitUrlParse = _interopRequireDefault(require("git-url-parse"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
Copyright 2019 Province of British Columbia

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at 

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Created by Patrick Simonian
*/
// utilities to parse the validated url

/**
 * returns information needed to use the contents api from a github url
 * @param {String} url the github url
 * @returns {Object} {owner, repo, filepath, ref (branch)}
 */
const extractInformationFromGithubUrl = url => {
  const githubParsed = (0, _gitUrlParse.default)(url);
  const {
    owner,
    name,
    filepath,
    ref
  } = githubParsed;
  return {
    owner,
    repo: name,
    filepath,
    ref
  };
};
/**
 * creates the GITHUB v3 contents api endpoint for a file
 * @param {String} repo
 * @param {String} owner
 * @param {String} path
 * @param {String} branch
 */


exports.extractInformationFromGithubUrl = extractInformationFromGithubUrl;

const createFetchFileRoute = (repo, owner, path, branch = '') => {
  const ref = branch === '' ? '' : `?ref=${branch}`;
  return `https://api.github.com/repos/${owner}/${repo}/contents/${path}${ref}`;
};

exports.createFetchFileRoute = createFetchFileRoute;